// This code is generated by pgen2/grammar.py

namespace grammar_nt {
  const int augassign = 512;
  const int and_expr = 513;
  const int and_test = 514;
  const int arg_group = 515;
  const int arglist = 516;
  const int arglist3 = 517;
  const int argument = 518;
  const int arith_expr = 519;
  const int array_item = 520;
  const int atom = 521;
  const int braced_var_sub = 522;
  const int char_literal = 523;
  const int class_literal = 524;
  const int class_literal_term = 525;
  const int comma_newline = 526;
  const int command_expr = 527;
  const int comp_for = 528;
  const int comp_op = 529;
  const int comparison = 530;
  const int dict = 531;
  const int dict_pair = 532;
  const int dq_string = 533;
  const int eggex = 534;
  const int end_stmt = 535;
  const int expr = 536;
  const int factor = 537;
  const int lambdef = 538;
  const int lhs_list = 539;
  const int name_type = 540;
  const int name_type_list = 541;
  const int not_test = 542;
  const int old_sh_array_literal = 543;
  const int or_test = 544;
  const int param = 545;
  const int param_group = 546;
  const int pat_else = 547;
  const int pat_exprs = 548;
  const int place_trailer = 549;
  const int power = 550;
  const int range_char = 551;
  const int range_expr = 552;
  const int re_alt = 553;
  const int re_atom = 554;
  const int re_flag = 555;
  const int regex = 556;
  const int repeat_op = 557;
  const int repeat_range = 558;
  const int sh_array_literal = 559;
  const int sh_command_sub = 560;
  const int shift_expr = 561;
  const int simple_var_sub = 562;
  const int splat_expr = 563;
  const int sq_string = 564;
  const int subscript = 565;
  const int subscriptlist = 566;
  const int term = 567;
  const int test = 568;
  const int testlist = 569;
  const int testlist_comp = 570;
  const int trailer = 571;
  const int type_expr = 572;
  const int xor_expr = 573;
  const int ysh_case_pat = 574;
  const int ysh_eager_arglist = 575;
  const int ysh_expr = 576;
  const int ysh_expr_sub = 577;
  const int ysh_expr_sub_2 = 578;
  const int ysh_func = 579;
  const int ysh_lazy_arglist = 580;
  const int ysh_mutation = 581;
  const int ysh_proc = 582;
  const int ysh_var_decl = 583;

}  // namespace grammar_nt
